BehaviorString

Struct BehaviorString 

pub struct BehaviorString;
The std lib’s String type behavior.

We currently use a CString from to ingest all String values. This might be unsafe if the string was instantiated by the caller without using rust’s instanciation mechanism. In that case, it would be safe to use a CStr. See https://doc.rust-lang.org/std/ffi/struct.CString.html